<?php

namespace Drupal\commerce_wallee\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\Response;

/**
 * Class WebhookController.
 */
class WebhookController extends ControllerBase {

  /**
   * {@inheritdoc}
   */
  public function content() {
    // Check if webhook URL is in use.
    if (!isset($_GET['gate'])) {
      $response = new Response();
      $response->setContent('Error');
      return $response;
    }

    $paymentGatewayStorage = \Drupal::entityTypeManager()->getStorage('commerce_payment_gateway')->loadByProperties(['configuration.webhook_url_gate' => $_GET['gate']]);
    if (count($paymentGatewayStorage) > 0 AND !current($paymentGatewayStorage) instanceof \Drupal\commerce_payment\Entity\PaymentGateway) {
      $response = new Response();
      $response->setContent('Error');
      return $response;
    }

    // Get data from webhook.
    $data_post = trim(file_get_contents('php://input'));
    if ($data_post != '') {

//      \Drupal::logger('commerce_wallee')->notice($data_post);

      $data = json_decode($data_post, true);
      if (isset($data['listenerEntityTechnicalName']) AND isset($data['entityId']) AND isset($data['spaceId'])) {

        if ($data['listenerEntityTechnicalName'] == 'Token') {
          $this->updateToken(current($paymentGatewayStorage), $data);
        }

        if ($data['listenerEntityTechnicalName'] == 'TokenVersion') {
          $this->updateTokenVersion(current($paymentGatewayStorage), $data);
        }

        if ($data['listenerEntityTechnicalName'] == 'Transaction') {
          $this->updateTransaction(current($paymentGatewayStorage), $data);
        }

      }
    }

    $response = new Response();
    $response->setContent('Ok');
    return $response;
  }

  /**
   * {@inheritdoc}
   */
  private function updateToken($paymentGatewayStorage, $data) {
    \Drupal::service('commerce_wallee.payment_sdk')->webhookToken($paymentGatewayStorage, $data);
  }

  /**
   * {@inheritdoc}
   */
  private function updateTokenVersion($paymentGatewayStorage, $data) {
    \Drupal::service('commerce_wallee.payment_sdk')->webhookTokenVersion($paymentGatewayStorage, $data);
  }

  /**
   * {@inheritdoc}
   */
  private function updateTransaction($paymentGatewayStorage, $data) {
    \Drupal::service('commerce_wallee.payment_sdk')->webhookTransaction($paymentGatewayStorage, $data);
  }
}
